Documentation
¶
Index ¶
- Constants
- type ContainerOverride
- type Fargate
- func (f *Fargate) Kill(ctx context.Context, w spawner.World) error
- func (f *Fargate) Name() string
- func (f *Fargate) Ps(ctx context.Context, g string) ([]*spawner.World, error)
- func (f *Fargate) Spawn(ctx context.Context, r io.Reader) (*spawner.World, error)
- func (f *Fargate) TaskAddr(ctx context.Context, t *ecs.Task) (*string, error)
- type Task
- type TaskDefinition
Constants ¶
const LastStatusPollInterval = time.Millisecond * time.Duration(500)
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ContainerOverride ¶
type Fargate ¶
type Fargate struct {
HostVersion string
// contains filtered or unexported fields
}
func NewFargate ¶
type Task ¶
type Task struct {
Arn *string `json:"arn"`
ClusterArn *string `json:"cluster_arn"`
Addr *string `json:"addr"`
}
Task contains the information required to contact or stop a running task. Spawner callers have to store this information if the want to be able to Kill the World.
type TaskDefinition ¶
type TaskDefinition struct {
// The task definition name is the identification name, usually composed by
// a user-defined task name and a revision number. Checkout the AWS console
// to find it.
Name *string `json:"name"`
// Cluster specifies where the task is to be executed. The cluster must be
// already present in the referred AWS ECS environment.
Cluster *string `json:"cluster"`
Subnets []*string `json:"subnets"`
SecurityGroups []*string `json:"security_groups"`
// A task is composed by a variable number of containers. Here we can
// override each one of them.
// This is the place where we specify the HW requirements and, using the
// "command override", how the tool is started.
Overrides []*ContainerOverride
}
func TaskDefinitionFrom ¶
func TaskDefinitionFrom(r io.Reader) (TaskDefinition, error)
Click to show internal directories.
Click to hide internal directories.